![Icon](https://github.com/LorenzoBunino/scappamento/raw/master/images/icon%40128.png)
# scappamento
[![License](https://img.shields.io/github/license/LorenzoBunino/scappamento)]()
[![Build Status](https://travis-ci.com/LorenzoBunino/scappamento.svg?branch=master)](https://travis-ci.com/LorenzoBunino/scappamento)
[![Coverage Status](https://coveralls.io/repos/github/LorenzoBunino/scappamento/badge.svg?branch=master)](https://coveralls.io/github/LorenzoBunino/scappamento?branch=master)
[![PyPI version](https://badge.fury.io/py/scappamento.svg)](https://pypi.org/project/scappamento/)
#### B2B automation for music stores

**scappamento** is a Python tool that acts as an intermediary between suppliers and ERP software.

Supported suppliers / platforms:
* Yamaha
* Fender
* Frenexport
* Suonostore
* acquistinretepa
* Mogar
* Hoshino Europe

:broccoli: